[Libreoffice-commits] .: 2 commits - accessibility/bridge automation/source crashrep/source cui/source extensions/inc extensions/source extensions/util forms/qa forms/source javainstaller2/src setup_native/source xmlsecurity/source

Caolán McNamara caolan at kemper.freedesktop.org
Mon Dec 6 01:17:07 PST 2010


 accessibility/bridge/source/java/WindowsAccessBridgeAdapter.cxx                    |    8 ++---
 automation/source/server/XMLParser.cxx                                             |   10 +++----
 crashrep/source/unx/main.cxx                                                       |    2 -
 crashrep/source/win32/soreport.cpp                                                 |    2 -
 cui/source/customize/cfg.cxx                                                       |    4 +-
 cui/source/customize/macropg.cxx                                                   |    2 -
 cui/source/customize/macropg.src                                                   |    2 -
 cui/source/dialogs/scriptdlg.cxx                                                   |    2 -
 cui/source/dialogs/showcols.cxx                                                    |    4 +-
 cui/source/inc/cuires.hrc                                                          |    2 -
 extensions/inc/propctrlr.hrc                                                       |    4 +-
 extensions/source/bibliography/framectr.cxx                                        |    2 -
 extensions/source/logging/loghandler.hxx                                           |    4 +-
 extensions/source/macosx/spotlight/OOoContentDataParser.m                          |    2 -
 extensions/source/plugin/base/xplugin.cxx                                          |    2 -
 extensions/source/propctrlr/cellbindinghelper.hxx                                  |    4 +-
 extensions/source/propctrlr/eventhandler.cxx                                       |    2 -
 extensions/source/propctrlr/formres.src                                            |    2 -
 extensions/source/propctrlr/formresid.hrc                                          |    2 -
 extensions/source/propctrlr/pcrcomponentcontext.hxx                                |    4 +-
 extensions/util/hidother.src                                                       |    4 +-
 forms/qa/complex/forms/CheckOGroupBoxModel.java                                    |    6 ++--
 forms/source/xforms/convert.hxx                                                    |    2 -
 forms/source/xforms/model_ui.cxx                                                   |    2 -
 javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/LinuxInstaller.java    |    4 +-
 javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/SolarisInstaller.java  |    4 +-
 javainstaller2/src/JavaSetup/org/openoffice/setup/InstallerHelper/LinuxHelper.java |   14 +++++-----
 javainstaller2/src/JavaSetup/org/openoffice/setup/Util/Controller.java             |    4 +-
 setup_native/source/win32/customactions/shellextensions/registerextensions.cxx     |   10 +++----
 setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx           |    6 ++--
 xmlsecurity/source/xmlsec/nss/certerrors.h                                         |    2 -
 31 files changed, 62 insertions(+), 62 deletions(-)

New commits:
commit e83930c5dbed08170ff43d26d5870f28f3482ad2
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Mon Dec 6 08:39:54 2010 +0000

    fix this up

diff --git a/extensions/source/propctrlr/eventhandler.cxx b/extensions/source/propctrlr/eventhandler.cxx
index d56747f..1de3bf0 100644
--- a/extensions/source/propctrlr/eventhandler.cxx
+++ b/extensions/source/propctrlr/eventhandler.cxx
@@ -220,7 +220,7 @@ namespace pcr
                     DESCRIBE_EVENT( "sdb",  "XRowSetApproveListener",       "approveCursorMove",        POSITIONING );
                     DESCRIBE_EVENT( "sdbc", "XRowSetListener",              "cursorMoved",              POSITIONED );
                     DESCRIBE_EVENT( "form", "XDatabaseParameterListener",   "approveParameter",         APPROVEPARAMETER );
-                    DESCRIBE_EVENT( "sdb",  "XSQLErrorListener",            "errorOccured",             ERROROCCURED );
+                    DESCRIBE_EVENT( "sdb",  "XSQLErrorListener",            "errorOccured",             ERROROCCURRED );
                     DESCRIBE_EVENT( "awt",  "XAdjustmentListener",          "adjustmentValueChanged",   ADJUSTMENTVALUECHANGED );
                 }
             }
commit 6d15557d6e1c386d0269828c318313b106e10545
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 12:56:38 2010 +0900

    Replace all occured, occurance etc.

diff --git a/accessibility/bridge/source/java/WindowsAccessBridgeAdapter.cxx b/accessibility/bridge/source/java/WindowsAccessBridgeAdapter.cxx
index cec5e01..e5807a6 100644
--- a/accessibility/bridge/source/java/WindowsAccessBridgeAdapter.cxx
+++ b/accessibility/bridge/source/java/WindowsAccessBridgeAdapter.cxx
@@ -94,17 +94,17 @@ Java_org_openoffice_accessibility_WindowsAccessBridgeAdapter_getProcessID(JNIEnv
     g_jcWindowsAccessBridgeAdapter = 
         static_cast< jclass > (pJNIEnv->NewGlobalRef(clazz));
     if (NULL == g_jcWindowsAccessBridgeAdapter) {
-        return 0; /* jni error occured */
+        return 0; /* jni error occurred */
     }
     g_jmRegisterTopWindow = 
         pJNIEnv->GetStaticMethodID(clazz, "registerTopWindow", "(ILcom/sun/star/accessibility/XAccessible;)V");
     if (0 == g_jmRegisterTopWindow) {
-        return 0; /* jni error occured */
+        return 0; /* jni error occurred */
     }
     g_jmRevokeTopWindow = 
         pJNIEnv->GetStaticMethodID(clazz, "revokeTopWindow", "(ILcom/sun/star/accessibility/XAccessible;)V");
     if (0 == g_jmRevokeTopWindow) {
-        return 0; /* jni error occured */
+        return 0; /* jni error occurred */
     }
     
     // Use the special protocol of XJavaVM.getJavaVM:  If the passed in
@@ -284,7 +284,7 @@ void handleWindowEvent(Window * pWindow, bool bShow)
                         (bShow) ? g_jmRegisterTopWindow : g_jmRevokeTopWindow, 
                         (jint) GetHWND(pWindow), joXAccessible );
 
-                    // Clear any exception that might have been occured.
+                    // Clear any exception that might have been occurred.
                     if (pJNIEnv->ExceptionCheck()) {
                         pJNIEnv->ExceptionClear();
                     }
diff --git a/automation/source/server/XMLParser.cxx b/automation/source/server/XMLParser.cxx
index cebd149..de35e72 100644
--- a/automation/source/server/XMLParser.cxx
+++ b/automation/source/server/XMLParser.cxx
@@ -622,11 +622,11 @@ void StatementCommand::HandleSAXParser()
                     }
                     else if ( pElementNode )
                     {
-                        USHORT nNthOccurance;
+                        USHORT nNthOccurrence;
                         if( (nParams & PARAM_USHORT_1) )
-                            nNthOccurance = nNr1;
+                            nNthOccurrence = nNr1;
                         else
-                            nNthOccurance = 1;
+                            nNthOccurrence = 1;
 
                         USHORT i;
                         NodeRef xNew;
@@ -638,10 +638,10 @@ void StatementCommand::HandleSAXParser()
                                 ElementNode* pNewElement = (ElementNode*)(&xNew);
                                 if ( aString1.Equals( pNewElement->GetNodeName() ) )
                                 {
-                                    if ( nNthOccurance > 1 )
+                                    if ( nNthOccurrence > 1 )
                                     {
                                         xNew.Clear();
-                                        nNthOccurance--;
+                                        nNthOccurrence--;
                                     }
                                 }
                                 else
diff --git a/crashrep/source/unx/main.cxx b/crashrep/source/unx/main.cxx
index 6f559bb..f005d5f 100644
--- a/crashrep/source/unx/main.cxx
+++ b/crashrep/source/unx/main.cxx
@@ -149,7 +149,7 @@ static string xml_encode( const string &rString )
     string temp = rString;
     string::size_type pos = 0;
 
-    // First replace all occurences of '&' because it may occur in further
+    // First replace all occurrences of '&' because it may occur in further
     // encoded chardters too
 
     for( pos = 0; (pos = temp.find( '&', pos )) != string::npos; pos += 4 )
diff --git a/crashrep/source/win32/soreport.cpp b/crashrep/source/win32/soreport.cpp
index b0704c2..a05d01a 100644
--- a/crashrep/source/win32/soreport.cpp
+++ b/crashrep/source/win32/soreport.cpp
@@ -570,7 +570,7 @@ static string xml_encode( const string &rString )
     string temp = rString;
     string::size_type pos = 0;
 
-    // First replace all occurences of '&' because it may occur in further
+    // First replace all occurrences of '&' because it may occur in further
     // encoded chardters too
 
     for( pos = 0; (pos = temp.find( '&', pos )) != string::npos; pos += 4 )
diff --git a/cui/source/customize/cfg.cxx b/cui/source/customize/cfg.cxx
index 5be1f05..c14309c 100644
--- a/cui/source/customize/cfg.cxx
+++ b/cui/source/customize/cfg.cxx
@@ -4379,7 +4379,7 @@ void ToolbarSaveInData::Reset()
         }
         catch ( uno::Exception& )
         {
-            // error occured removing the settings
+            // error occurred removing the settings
             // TODO - add error dialog in future?
         }
     }
@@ -4572,7 +4572,7 @@ void ToolbarSaveInData::RemoveToolbar( SvxConfigEntry* pToolbar )
     }
     catch ( uno::Exception& )
     {
-        // error occured removing the settings
+        // error occurred removing the settings
     }
 }
 
diff --git a/cui/source/customize/macropg.cxx b/cui/source/customize/macropg.cxx
index 169113d..bd2d757 100644
--- a/cui/source/customize/macropg.cxx
+++ b/cui/source/customize/macropg.cxx
@@ -325,7 +325,7 @@ void _SvxMacroTabPage::InitResources()
     aDisplayNames.push_back( EventDisplayName( "approveCursorMove",     RID_SVXSTR_EVENT_POSITIONING ) );
     aDisplayNames.push_back( EventDisplayName( "cursorMoved",           RID_SVXSTR_EVENT_POSITIONED ) );
     aDisplayNames.push_back( EventDisplayName( "approveParameter",      RID_SVXSTR_EVENT_APPROVEPARAMETER ) );
-    aDisplayNames.push_back( EventDisplayName( "errorOccured",          RID_SVXSTR_EVENT_ERROROCCURED ) );
+    aDisplayNames.push_back( EventDisplayName( "errorOccurred",          RID_SVXSTR_EVENT_ERROROCCURRED ) );
     aDisplayNames.push_back( EventDisplayName( "adjustmentValueChanged",   RID_SVXSTR_EVENT_ADJUSTMENTVALUECHANGED ) );
 }
 
diff --git a/cui/source/customize/macropg.src b/cui/source/customize/macropg.src
index fc4560b..f194c44 100644
--- a/cui/source/customize/macropg.src
+++ b/cui/source/customize/macropg.src
@@ -267,7 +267,7 @@ String RID_SVXSTR_EVENT_CONFIRMDELETE
 {
     Text [ en-US ] = "Confirm deletion" ;
 };
-String RID_SVXSTR_EVENT_ERROROCCURED
+String RID_SVXSTR_EVENT_ERROROCCURRED
 {
     Text [ en-US ] = "Error occurred" ;
 };
diff --git a/cui/source/dialogs/scriptdlg.cxx b/cui/source/dialogs/scriptdlg.cxx
index 6aa0676..3f7f70e 100644
--- a/cui/source/dialogs/scriptdlg.cxx
+++ b/cui/source/dialogs/scriptdlg.cxx
@@ -1576,7 +1576,7 @@ BOOL SFTreeListBox::dialogSort2( Reference< browse::XBrowseNode > node1,
     }
     else if ( aException.getValueType() == ::getCppuType( ( const provider::ScriptFrameworkErrorException* ) NULL ) )
     {
-        // A Script Framework error has occured
+        // A Script Framework error has occurred
         provider::ScriptFrameworkErrorException sfe;
         aException >>= sfe;
         return GetErrorMessage( sfe );
diff --git a/cui/source/dialogs/showcols.cxx b/cui/source/dialogs/showcols.cxx
index aaee4e7..5cb8867 100644
--- a/cui/source/dialogs/showcols.cxx
+++ b/cui/source/dialogs/showcols.cxx
@@ -86,7 +86,7 @@ IMPL_LINK( FmShowColsDialog, OnClickedOk, Button*, EMPTYARG )
                 }
                 catch(...)
                 {
-                    DBG_ERROR("FmShowColsDialog::OnClickedOk Exception occured!");
+                    DBG_ERROR("FmShowColsDialog::OnClickedOk Exception occurred!");
                 }
             }
         }
@@ -124,7 +124,7 @@ void FmShowColsDialog::SetColumns(const ::com::sun::star::uno::Reference< ::com:
         }
         catch(...)
         {
-            DBG_ERROR("FmShowColsDialog::SetColumns Exception occured!");
+            DBG_ERROR("FmShowColsDialog::SetColumns Exception occurred!");
         }
 
         // if the col is hidden, put it into the list
diff --git a/cui/source/inc/cuires.hrc b/cui/source/inc/cuires.hrc
old mode 100755
new mode 100644
index eb4a43f..24d3ce2
--- a/cui/source/inc/cuires.hrc
+++ b/cui/source/inc/cuires.hrc
@@ -396,7 +396,7 @@
 #define RID_SVXSTR_EVENT_POSITIONING            (RID_SVX_START + 1094)
 #define RID_SVXSTR_EVENT_POSITIONED             (RID_SVX_START + 1095)
 #define RID_SVXSTR_EVENT_APPROVEPARAMETER       (RID_SVX_START + 1096)
-#define RID_SVXSTR_EVENT_ERROROCCURED           (RID_SVX_START + 1097)
+#define RID_SVXSTR_EVENT_ERROROCCURRED           (RID_SVX_START + 1097)
 #define RID_SVXSTR_EVENT_ADJUSTMENTVALUECHANGED (RID_SVX_START + 1098)
 #define RID_SVXSTR_EVENT_RESETTED               (RID_SVX_START + 1099)
 #define RID_SVXSTR_EVENT_SUBCOMPONENT_OPENED                (RID_SVX_START + 1170)
diff --git a/extensions/inc/propctrlr.hrc b/extensions/inc/propctrlr.hrc
index ab11bf4..d6006c1 100644
--- a/extensions/inc/propctrlr.hrc
+++ b/extensions/inc/propctrlr.hrc
@@ -246,7 +246,7 @@
 #define UID_BRWEVT_POSITIONING                  ( HID_PROPC_START + 214)
 #define UID_BRWEVT_POSITIONED                   ( HID_PROPC_START + 215)
 #define UID_BRWEVT_APPROVEPARAMETER             ( HID_PROPC_START + 216)
-#define UID_BRWEVT_ERROROCCURED                 ( HID_PROPC_START + 217)
+#define UID_BRWEVT_ERROROCCURRED                 ( HID_PROPC_START + 217)
 #define UID_BRWEVT_ADJUSTMENTVALUECHANGED       ( HID_PROPC_START + 218)
 #define HID_PROP_XML_DATA_MODEL                 ( HID_PROPC_START + 219)
 #define HID_PROP_BIND_EXPRESSION                ( HID_PROPC_START + 220)
@@ -283,7 +283,7 @@
 #define HID_EVT_AFTERUPDATE                     ( HID_PROPC_START + 251)
 #define HID_EVT_BEFOREUPDATE                    ( HID_PROPC_START + 252)
 #define HID_EVT_CONFIRMDELETE                   ( HID_PROPC_START + 253)
-#define HID_EVT_ERROROCCURED                    ( HID_PROPC_START + 254)
+#define HID_EVT_ERROROCCURRED                    ( HID_PROPC_START + 254)
 #define HID_EVT_FOCUSGAINED                     ( HID_PROPC_START + 255)
 #define HID_EVT_FOCUSLOST                       ( HID_PROPC_START + 256)
 #define HID_EVT_ITEMSTATECHANGED                ( HID_PROPC_START + 257)
diff --git a/extensions/source/bibliography/framectr.cxx b/extensions/source/bibliography/framectr.cxx
index 0e0fb80..4867cf7 100644
--- a/extensions/source/bibliography/framectr.cxx
+++ b/extensions/source/bibliography/framectr.cxx
@@ -411,7 +411,7 @@ sal_Bool BibFrameController_Impl::SaveModified(const Reference< form::runtime::X
         }
         catch(Exception&)
         {
-            DBG_ERROR("SaveModified: Exception occured!");
+            DBG_ERROR("SaveModified: Exception occurred!");
         }
 
         bInserted = bIsNew && bResult;
diff --git a/extensions/source/logging/loghandler.hxx b/extensions/source/logging/loghandler.hxx
index 34f93d4..a4e2bf2 100644
--- a/extensions/source/logging/loghandler.hxx
+++ b/extensions/source/logging/loghandler.hxx
@@ -123,13 +123,13 @@ namespace logging
 
         /** retrieves our formatter's heading, encoded with our encoding
 
-            @return <TRUE/> in case of success, <FALSE/> if any error occured
+            @return <TRUE/> in case of success, <FALSE/> if any error occurred
         */
         bool    getEncodedHead( ::rtl::OString& _out_rHead ) const;
 
         /** retrieves our formatter's tail, encoded with our encoding
 
-            @return <TRUE/> in case of success, <FALSE/> if any error occured
+            @return <TRUE/> in case of success, <FALSE/> if any error occurred
         */
         bool    getEncodedTail( ::rtl::OString& _out_rTail ) const;
 
diff --git a/extensions/source/macosx/spotlight/OOoContentDataParser.m b/extensions/source/macosx/spotlight/OOoContentDataParser.m
index 11c3ec0..f485607 100644
--- a/extensions/source/macosx/spotlight/OOoContentDataParser.m
+++ b/extensions/source/macosx/spotlight/OOoContentDataParser.m
@@ -110,7 +110,7 @@
 - (void)parser:(NSXMLParser *)parser parseErrorOccurred:(NSError *)parseError
 {
     //NSLog(@"parsing finished with error");
-    NSLog([NSString stringWithFormat:@"An error occured parsing the document. (Error %i, Description: %@, Line: %i, Column: %i)", [parseError code], 
+    NSLog([NSString stringWithFormat:@"An error occurred parsing the document. (Error %i, Description: %@, Line: %i, Column: %i)", [parseError code], 
         [[parser parserError] localizedDescription], [parser lineNumber],
         [parser columnNumber]]);
     
diff --git a/extensions/source/plugin/base/xplugin.cxx b/extensions/source/plugin/base/xplugin.cxx
index c645195..882ea65 100644
--- a/extensions/source/plugin/base/xplugin.cxx
+++ b/extensions/source/plugin/base/xplugin.cxx
@@ -982,7 +982,7 @@ PluginInputStream::~PluginInputStream()
     {
         ByteString aFileName( aFile, m_pPlugin->getTextEncoding() );
         if( m_pPlugin->getPluginComm() && m_nMode != -1 )
-            // mode -1 means either an error occured,
+            // mode -1 means either an error occurred,
             // or the plugin is already disposing
         {
             m_pPlugin->getPluginComm()->addFileToDelete( aFile );
diff --git a/extensions/source/propctrlr/cellbindinghelper.hxx b/extensions/source/propctrlr/cellbindinghelper.hxx
index 8fe262b..a6767c4 100644
--- a/extensions/source/propctrlr/cellbindinghelper.hxx
+++ b/extensions/source/propctrlr/cellbindinghelper.hxx
@@ -121,7 +121,7 @@ namespace pcr
             @precond
                 The binding is a valid cell binding, or <NULL/>
             @return
-                <FALSE/> if and only if an error occured and no valid address could be obtained
+                <FALSE/> if and only if an error occurred and no valid address could be obtained
             @see isCellBinding
         */
         bool            getAddressFromCellBinding(
@@ -205,7 +205,7 @@ namespace pcr
                         ) const;
 
         /** retrieves the index of the sheet which our control belongs to
-            @return the index of the sheet which our control belongs to or -1, if an error occured
+            @return the index of the sheet which our control belongs to or -1, if an error occurred
         */
         sal_Int16       getControlSheetIndex(
                             ::com::sun::star::uno::Reference< ::com::sun::star::sheet::XSpreadsheet >& _out_rxSheet
diff --git a/extensions/source/propctrlr/formres.src b/extensions/source/propctrlr/formres.src
index 1170c89..c486643 100644
--- a/extensions/source/propctrlr/formres.src
+++ b/extensions/source/propctrlr/formres.src
@@ -775,7 +775,7 @@ String RID_STR_EVT_CONFIRMDELETE
 {
     Text [ en-US ] = "Confirm deletion" ;
 };
-String RID_STR_EVT_ERROROCCURED
+String RID_STR_EVT_ERROROCCURRED
 {
     Text [ en-US ] = "Error occurred" ;
 };
diff --git a/extensions/source/propctrlr/formresid.hrc b/extensions/source/propctrlr/formresid.hrc
index 4024e2b..9ebb5c3 100644
--- a/extensions/source/propctrlr/formresid.hrc
+++ b/extensions/source/propctrlr/formresid.hrc
@@ -189,7 +189,7 @@
 #define RID_STR_EVT_POSITIONING				( RID_FORMBROWSER_START + 160 )
 #define RID_STR_EVT_POSITIONED				( RID_FORMBROWSER_START + 161 )
 #define RID_STR_EVT_APPROVEPARAMETER		( RID_FORMBROWSER_START + 162 )
-#define RID_STR_EVT_ERROROCCURED			( RID_FORMBROWSER_START + 163 )
+#define RID_STR_EVT_ERROROCCURRED			( RID_FORMBROWSER_START + 163 )
 #define RID_STR_EVENTS						( RID_FORMBROWSER_START + 164 )
 #define RID_STR_ESCAPE_PROCESSING			( RID_FORMBROWSER_START + 165 )
     // FREE
diff --git a/extensions/source/propctrlr/pcrcomponentcontext.hxx b/extensions/source/propctrlr/pcrcomponentcontext.hxx
index bfd52cd..d050f3a 100644
--- a/extensions/source/propctrlr/pcrcomponentcontext.hxx
+++ b/extensions/source/propctrlr/pcrcomponentcontext.hxx
@@ -102,7 +102,7 @@ namespace pcr
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -113,7 +113,7 @@ namespace pcr
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
diff --git a/extensions/util/hidother.src b/extensions/util/hidother.src
index 48f2e8e..0ad1e24 100644
--- a/extensions/util/hidother.src
+++ b/extensions/util/hidother.src
@@ -104,7 +104,7 @@ hidspecial HID_EVT_APPROVEROWCHANGE             { HelpId = HID_EVT_APPROVEROWCHA
 hidspecial HID_EVT_BEFOREUPDATE                 { HelpId = HID_EVT_BEFOREUPDATE; }
 hidspecial HID_EVT_CHANGED                      { HelpId = HID_EVT_CHANGED; }
 hidspecial HID_EVT_CONFIRMDELETE                { HelpId = HID_EVT_CONFIRMDELETE; }
-hidspecial HID_EVT_ERROROCCURED                 { HelpId = HID_EVT_ERROROCCURED; }
+hidspecial HID_EVT_ERROROCCURRED                 { HelpId = HID_EVT_ERROROCCURRED; }
 hidspecial HID_EVT_FOCUSGAINED                  { HelpId = HID_EVT_FOCUSGAINED; }
 hidspecial HID_EVT_FOCUSLOST                    { HelpId = HID_EVT_FOCUSLOST; }
 hidspecial HID_EVT_ITEMSTATECHANGED             { HelpId = HID_EVT_ITEMSTATECHANGED; }
@@ -355,7 +355,7 @@ hidspecial UID_BRWEVT_APPROVEROWCHANGE          { HelpId = UID_BRWEVT_APPROVEROW
 hidspecial UID_BRWEVT_BEFOREUPDATE              { HelpId = UID_BRWEVT_BEFOREUPDATE; }
 hidspecial UID_BRWEVT_CHANGED                   { HelpId = UID_BRWEVT_CHANGED; }
 hidspecial UID_BRWEVT_CONFIRMDELETE             { HelpId = UID_BRWEVT_CONFIRMDELETE; }
-hidspecial UID_BRWEVT_ERROROCCURED              { HelpId = UID_BRWEVT_ERROROCCURED; }
+hidspecial UID_BRWEVT_ERROROCCURRED              { HelpId = UID_BRWEVT_ERROROCCURRED; }
 hidspecial UID_BRWEVT_FOCUSGAINED               { HelpId = UID_BRWEVT_FOCUSGAINED; }
 hidspecial UID_BRWEVT_FOCUSLOST                 { HelpId = UID_BRWEVT_FOCUSLOST; }
 hidspecial UID_BRWEVT_ITEMSTATECHANGED          { HelpId = UID_BRWEVT_ITEMSTATECHANGED; }
diff --git a/forms/qa/complex/forms/CheckOGroupBoxModel.java b/forms/qa/complex/forms/CheckOGroupBoxModel.java
old mode 100755
new mode 100644
index b1d42ba..4ee39e3
--- a/forms/qa/complex/forms/CheckOGroupBoxModel.java
+++ b/forms/qa/complex/forms/CheckOGroupBoxModel.java
@@ -88,13 +88,13 @@ public class CheckOGroupBoxModel extends ComplexTestCase {
             xPropSet.setPropertyValues(boundPropsToTest, newValue);
         } catch (com.sun.star.beans.PropertyVetoException e) {
             e.printStackTrace((PrintWriter)log);
-            failed("Exception occured while trying to change the properties.");
+            failed("Exception occurred while trying to change the properties.");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
             e.printStackTrace((PrintWriter)log);
-            failed("Exception occured while trying to change the properties.");
+            failed("Exception occurred while trying to change the properties.");
         } catch (com.sun.star.lang.WrappedTargetException e) {
             e.printStackTrace((PrintWriter)log);
-            failed("Exception occured while trying to change the properties.");
+            failed("Exception occurred while trying to change the properties.");
         } // end of try-catch
 
         assure("Listener was not called.", ml.wasListenerCalled());
diff --git a/forms/source/xforms/convert.hxx b/forms/source/xforms/convert.hxx
index 86c624d..61a2a07 100644
--- a/forms/source/xforms/convert.hxx
+++ b/forms/source/xforms/convert.hxx
@@ -99,7 +99,7 @@ public:
             sal_Int16   _nWhitespaceTreatment
     );
 
-    /** replace all occurences 0x08, 0x0A, 0x0D with 0x20
+    /** replace all occurrences 0x08, 0x0A, 0x0D with 0x20
     */
     static ::rtl::OUString replaceWhitespace( const ::rtl::OUString& _rString );
 
diff --git a/forms/source/xforms/model_ui.cxx b/forms/source/xforms/model_ui.cxx
index 48b6695..dd433c1 100644
--- a/forms/source/xforms/model_ui.cxx
+++ b/forms/source/xforms/model_ui.cxx
@@ -139,7 +139,7 @@ void lcl_OutPosition( OUStringBuffer& rBuffer,
 {
     OSL_ENSURE( xNode->getParentNode().is(), "need parent" );
 
-    // count # of occurences of this node
+    // count # of occurrences of this node
     sal_Int32 nFound = 0;
     sal_Int32 nPosition = -1;
     if( xNode->getParentNode().is() )
diff --git a/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/LinuxInstaller.java b/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/LinuxInstaller.java
old mode 100755
new mode 100644
index 204c9e1..e8ecb7d
--- a/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/LinuxInstaller.java
+++ b/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/LinuxInstaller.java
@@ -285,7 +285,7 @@ public class LinuxInstaller extends Installer {
                 if ( returnValue == 0 ) {
                     log = rpmCommand + "<br><b>Returns: " + returnValue + " Successful installation</b><br>";
                     LogManager.addCommandsLogfileComment(log);
-                } else {    // an error occured during installation 
+                } else {    // an error occurred during installation 
                     if ( packageData.installCanFail() ) {
                         log = rpmCommand + "<br><b>Returns: " + returnValue + " Problem during installation. Can be ignored.</b><br>";
                         LogManager.addCommandsLogfileComment(log);
@@ -407,7 +407,7 @@ public class LinuxInstaller extends Installer {
             if ( returnValue == 0 ) {
                 log = rpmCommand + "<br><b>Returns: " + returnValue + " Successful uninstallation</b><br>";
                 LogManager.addCommandsLogfileComment(log);                        
-            } else {    // an error occured during installation                    
+            } else {    // an error occurred during installation                    
                 if ( packageData.uninstallCanFail() ) {
                     log = rpmCommand + "<br><b>Returns: " + returnValue + " Problem during uninstallation. Can be ignored.</b><br>";
                     LogManager.addCommandsLogfileComment(log);
diff --git a/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/SolarisInstaller.java b/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/SolarisInstaller.java
old mode 100755
new mode 100644
index 3bcdd34..b6a0b41
--- a/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/SolarisInstaller.java
+++ b/javainstaller2/src/JavaSetup/org/openoffice/setup/Installer/SolarisInstaller.java
@@ -219,7 +219,7 @@ public class SolarisInstaller extends Installer {
                 if ( returnValue == 0 ) {
                     log = pkgCommand + "<br><b>Returns: " + returnValue + " Successful installation</b><br>";
                     LogManager.addCommandsLogfileComment(log);                        
-                } else {    // an error occured during installation
+                } else {    // an error occurred during installation
                     if ( packageData.installCanFail() ) {
                         log = pkgCommand + "<br><b>Returns: " + returnValue + " Problem during installation. Can be ignored.</b><br>";
                         LogManager.addCommandsLogfileComment(log);
@@ -307,7 +307,7 @@ public class SolarisInstaller extends Installer {
         if ( returnValue == 0 ) {
             log = pkgCommand + "<br><b>Returns: " + returnValue + " Successful uninstallation</b><br>";
             LogManager.addCommandsLogfileComment(log);                        
-        } else {    // an error occured during installation                    
+        } else {    // an error occurred during installation                    
             if ( packageData.uninstallCanFail() ) {
                 log = pkgCommand + "<br><b>Returns: " + returnValue + " Problem during uninstallation. Can be ignored.</b><br>";
                 LogManager.addCommandsLogfileComment(log);
diff --git a/javainstaller2/src/JavaSetup/org/openoffice/setup/InstallerHelper/LinuxHelper.java b/javainstaller2/src/JavaSetup/org/openoffice/setup/InstallerHelper/LinuxHelper.java
old mode 100755
new mode 100644
index fb8bfa9..666a1c1
--- a/javainstaller2/src/JavaSetup/org/openoffice/setup/InstallerHelper/LinuxHelper.java
+++ b/javainstaller2/src/JavaSetup/org/openoffice/setup/InstallerHelper/LinuxHelper.java
@@ -111,7 +111,7 @@ import java.util.Vector;public class LinuxHelper {
 
     private HashMap analyzeVersionString(String versionString) {
         
-        boolean errorOccured = false;
+        boolean errorOccurred = false;
         
         Integer micro = null;
         Integer minor = null;
@@ -131,14 +131,14 @@ import java.util.Vector;public class LinuxHelper {
                 versionString = versionString.substring(0, pos);
             } catch (IndexOutOfBoundsException ex) {
                 System.err.println("Error: Could not get substring from " + versionString);
-                errorOccured = true;
+                errorOccurred = true;
             }
             try {
                 int releaseInt = Integer.parseInt(releaseString);
                 release = new Integer(releaseInt);
             } catch (NumberFormatException ex) {
                 System.err.println("Error: Could not convert " + releaseString + " to integer");                            
-                errorOccured = true;
+                errorOccurred = true;
             }
         }
 
@@ -166,7 +166,7 @@ import java.util.Vector;public class LinuxHelper {
                 versionString = versionString.substring(0, pos);
             } catch (IndexOutOfBoundsException ex) {
                 System.err.println("Error: Could not get substring from " + versionString);            
-                errorOccured = true;                
+                errorOccurred = true;                
             }
 
             pos = versionString.lastIndexOf(".");
@@ -176,7 +176,7 @@ import java.util.Vector;public class LinuxHelper {
                     majorString = versionString.substring(0, pos);
                 } catch (IndexOutOfBoundsException ex) {
                     System.err.println("Error: Could not get substring from " + versionString);            
-                    errorOccured = true;
+                    errorOccurred = true;
                 }
                 try {
                     int microInt = Integer.parseInt(microString);
@@ -188,7 +188,7 @@ import java.util.Vector;public class LinuxHelper {
                 } catch (NumberFormatException ex) {
                     System.err.println("Error: Could not convert " + microString + "," + 
                                        minorString + " or " + majorString + " to integer");                            
-                    errorOccured = true;
+                    errorOccurred = true;
                 }
             }
         }
@@ -199,7 +199,7 @@ import java.util.Vector;public class LinuxHelper {
         // if ( minorString == null ) { minorString = ""; }
         // System.err.println("Major " + majorString + " Minor: " + minorString + " Micro: " + microString + " Release: " + releaseString);
         
-        if ( errorOccured ) {
+        if ( errorOccurred ) {
             micro = null;
             minor = null;
             major = null;
diff --git a/setup_native/source/win32/customactions/shellextensions/registerextensions.cxx b/setup_native/source/win32/customactions/shellextensions/registerextensions.cxx
index ca43eea..47a4fea 100644
--- a/setup_native/source/win32/customactions/shellextensions/registerextensions.cxx
+++ b/setup_native/source/win32/customactions/shellextensions/registerextensions.cxx
@@ -268,7 +268,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
                     }
                     else
                     {
-                        mystr = "An error occured during removing content of " + sCompleteFileName;
+                        mystr = "An error occurred during removing content of " + sCompleteFileName;
                         // MessageBox(NULL, mystr.c_str(), "Error removing directory", MB_OK);
                     }
                 }
@@ -282,7 +282,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
                     }
                     else
                     {
-                        mystr = "An error occured during removal of file " + sCompleteFileName;
+                        mystr = "An error occurred during removal of file " + sCompleteFileName;
                         // MessageBox(NULL, mystr.c_str(), "Error removing file", MB_OK);
                     }
                 }
@@ -307,7 +307,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
         }
         else
         {
-            mystr = "An error occured during removal of empty directory " + sPath;
+            mystr = "An error occurred during removal of empty directory " + sPath;
             // MessageBox(NULL, mystr.c_str(), "Error removing directory", MB_OK);
             bDirectoryRemoved = false;
         }
@@ -355,7 +355,7 @@ extern "C" UINT __stdcall RegisterExtensions(MSIHANDLE handle)
 //         }
 //         else
 //         {
-//             mystr = "An error occured during execution!";
+//             mystr = "An error occurred during execution!";
 //             MessageBox(NULL, mystr.c_str(), "Command", MB_OK);
 //         }
         
@@ -420,7 +420,7 @@ extern "C" UINT __stdcall RemoveExtensions(MSIHANDLE handle)
 //     }
 //     else
 //     {
-//         mystr = "An error occured during execution!";
+//         mystr = "An error occurred during execution!";
 //         MessageBox(NULL, mystr.c_str(), "Main methode", MB_OK);
 //     }
 
diff --git a/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx b/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
index 3c8e348..7ab7da4 100644
--- a/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
+++ b/setup_native/source/win32/customactions/shellextensions/vistaspecial.cxx
@@ -132,7 +132,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
                     }
                     else
                     {
-                        mystr = "An error occured during removing content of " + sCompleteFileName;
+                        mystr = "An error occurred during removing content of " + sCompleteFileName;
                         // MessageBox(NULL, mystr.c_str(), "Error removing directory", MB_OK);
                     }
                 }
@@ -146,7 +146,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
                     }
                     else
                     {
-                        mystr = "An error occured during removal of file " + sCompleteFileName;
+                        mystr = "An error occurred during removal of file " + sCompleteFileName;
                         // MessageBox(NULL, mystr.c_str(), "Error removing file", MB_OK);
                     }
                 }
@@ -171,7 +171,7 @@ static BOOL RemoveCompleteDirectory( std::_tstring sPath )
         }
         else
         {
-            mystr = "An error occured during removal of empty directory " + sPath;
+            mystr = "An error occurred during removal of empty directory " + sPath;
             // MessageBox(NULL, mystr.c_str(), "Error removing directory", MB_OK);
             bDirectoryRemoved = false;
         }
diff --git a/xmlsecurity/source/xmlsec/nss/certerrors.h b/xmlsecurity/source/xmlsec/nss/certerrors.h
index c2b96c2..b1c9697 100644
--- a/xmlsecurity/source/xmlsec/nss/certerrors.h
+++ b/xmlsecurity/source/xmlsec/nss/certerrors.h
@@ -370,7 +370,7 @@ an existing cert, but that is not the same cert."},
 
 {SEC_ERROR_BAD_INFO_ACCESS_LOCATION, "Bad information access location in cert extension"},
 
-{SEC_ERROR_LIBPKIX_INTERNAL, "Libpkix internal error occured during cert validation."},
+{SEC_ERROR_LIBPKIX_INTERNAL, "Libpkix internal error occurred during cert validation."},
 
 #if ( NSS_VMAJOR > 3 ) || ( NSS_VMAJOR == 3 && NSS_VMINOR > 12 ) || ( NSS_VMAJOR == 3 && NSS_VMINOR == 12 && NSS_VPATCH > 2 )
 // following 3 errors got first used in NSS 3.12.3


More information about the Libreoffice-commits mailing list
diff --git a/javainstaller2/src/JavaSetup/org/openoffice/setup/Util/Controller.java b/javainstaller2/src/JavaSetup/org/openoffice/setup/Util/Controller.java
old mode 100755
new mode 100644
index 37b56ca..c473655
--- a/javainstaller2/src/JavaSetup/org/openoffice/setup/Util/Controller.java
+++ b/javainstaller2/src/JavaSetup/org/openoffice/setup/Util/Controller.java
@@ -124,8 +124,8 @@ public class Controller {
             // }
 
             installData.setSystemLanguages(realVector);
-        } else {    // an error occured                    
-            log = pkgCommand + "<br><b>Returns: " + returnValue + " An error occured</b><br>";
+        } else {    // an error occurred                    
+            log = pkgCommand + "<br><b>Returns: " + returnValue + " An error occurred</b><br>";
             LogManager.addCommandsLogfileComment(log);
             System.err.println("Error in command: " + pkgCommand);
             for (int i = 0; i < returnErrorVector.size(); i++) {